==> oppl2-oppl2-2.1.2-sources.jar: org/coode/oppl/InstantiatedOPPLScript.java <==
/**
 * Copyright (C) 2008, University of Manchester
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate.  Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.coode.oppl;

import org.semanticweb.owlapi.model.OWLObject;

/** Interface representing an instantiated OPPL Script
 * 
 * @author Luigi Iannone */
public interface InstantiatedOPPLScript extends OPPLScript {
    /** Adds the value o to the Variable v in this InstantiatedOPPLScript
     * 
     * @param v
     *            v
     * @param o
     *            o */
    void instantiate(Variable<?> v, OWLObject o);

    /** @return true if valid */
    boolean isValid();
}

==> oppl2-oppl2-5.0.0-sources.jar: org/coode/oppl/InstantiatedOPPLScript.java <==
/**
 * Copyright (C) 2008, University of Manchester
 *
 * Modifications to the initial code base are copyright of their
 * respective authors, or their employers as appropriate.  Authorship
 * of the modifications may be determined from the ChangeLog placed at
 * the end of this file.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.coode.oppl;

import org.semanticweb.owlapi.model.OWLObject;

/**
 * Interface representing an instantiated OPPL Script
 * 
 * @author Luigi Iannone
 */
public interface InstantiatedOPPLScript extends OPPLScript {

    /**
     * Adds the value o to the Variable v in this InstantiatedOPPLScript
     * 
     * @param v
     *        v
     * @param o
     *        o
     */
    void instantiate(Variable<?> v, OWLObject o);

    /**
     * @return true if valid
     */
    boolean isValid();
}
